/*
 * Home Health Grouper
 * Developer for the Center for Medicare and Medicaid Services CMS
 * by 3M Health Information Systems  for CMS Home Health.
 *
 * All code is provided as is.
 */
package com.mmm.cms.homehealth.vut.oasis;

import com.mmm.cms.homehealth.vut.proto.CollectionValidationEditsIF;
import com.mmm.cms.homehealth.vut.proto.OasisEditIF;
import com.mmm.cms.homehealth.vut.proto.OasisEditsEN;
import com.mmm.cms.homehealth.proto.HomeHealthRecordIF;
import com.mmm.cms.homehealth.proto.HomeHealthRecord_C1_IF;
import com.mmm.cms.homehealth.proto.RecordItemValidatorIF;
import com.mmm.cms.homehealth.vut.HHOasisDataItem;
import com.mmm.cms.homehealth.vut.OasisValidationEdit;
import com.mmm.cms.util.IntegerUtils;
import com.mmm.cms.util.ValidateUtils;
import static com.mmm.cms.util.ValidateUtils.ARRAY_DOUBLE_ZERO_ONE_TWO_THREE;
import static com.mmm.cms.util.ValidateUtils.ARRAY_DOUBLE_ZERO_ONE_TWO_THREE_FOUR;
import java.util.List;

/**
 * Validates Pressure Ulcers for Stage 1 thru 4, and Non-staging pressure ulcers
 * for edits: 3060, 4130, 4140,4150, 4160, 4170, 4210, 5110, 5120, 5130
 *
 * @author 3M Health Information Systems for CMS Home Health
 */
public class ValidatePressureUlcer_OASIS_C1 extends AbstractClinicalItemValidator implements RecordItemValidatorIF {

    /**
     * Creates item validator for the HomeHealthRecord_C1_IF class
     */
    public ValidatePressureUlcer_OASIS_C1() {
        super(HomeHealthRecord_C1_IF.class);
    }

    /**
     * returns the edit list
     *
     * @return non-null list of edits for this validator
     */
    public List<OasisEditIF> getEditIdsUsed() {
        return super.getEditIdsUsed_base(OasisEditsEN.EDIT_3060, 
                OasisEditsEN.EDIT_4130, OasisEditsEN.EDIT_4140,
                OasisEditsEN.EDIT_4150, OasisEditsEN.EDIT_4160, 
                OasisEditsEN.EDIT_4170, OasisEditsEN.EDIT_4210, 
                OasisEditsEN.EDIT_5110, OasisEditsEN.EDIT_5120, 
                OasisEditsEN.EDIT_5130);
    }

    public int validate(HomeHealthRecordIF record, CollectionValidationEditsIF edits) {
        int count = 0;
        final String assessmentReason = record.getASSMT_REASON();

        if (ValidateUtils.isValidValue(assessmentReason, AbstractItemValidator.ASSESSMENT_1_3_4_5_9_ONLY)) {
            if (record instanceof HomeHealthRecord_C1_IF) {
                final HomeHealthRecord_C1_IF recordC = (HomeHealthRecord_C1_IF) record;
                final String UNHLD_STG2_PRSR_ULCR = recordC.getUNHLD_STG2_PRSR_ULCR();
                final String STG_PRBLM_ULCER = recordC.getSTG_PRBLM_ULCER();
                final String NBR_PRSULC_STG1 = recordC.getNBR_PRSULC_STG1();
                final String NBR_PRSULC_STG2 = recordC.getNBR_PRSULC_STG2();
                final String NBR_PRSULC_STG3 = recordC.getNBR_PRSULC_STG3();
                final String NBR_PRSULC_STG4 = recordC.getNBR_PRSULC_STG4();
                final String NSTG_CVRG = recordC.getNSTG_CVRG();
                final String NSTG_DEEP_TISUE = recordC.getNSTG_DEEP_TISUE();
                final String NSTG_DRSG = recordC.getNSTG_DRSG();
                final String STUS_PRBLM_PRSR_ULCR = recordC.getSTUS_PRBLM_PRSR_ULCR();
                final boolean isRFA_1_3_9 = ValidateUtils.isValidValue(record.getASSMT_REASON(), AbstractItemValidator.ASSESSMENT_1_3_9_ONLY);

                if (!ValidateUtils.isEmpty(UNHLD_STG2_PRSR_ULCR) && !ValidateUtils.isNumeric(UNHLD_STG2_PRSR_ULCR)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1306_UNHLD_STG2_PRSR_ULCR, UNHLD_STG2_PRSR_ULCR)));
                }

                if (!ValidateUtils.isEmptyCaret(NBR_PRSULC_STG2) && !ValidateUtils.isNumeric(NBR_PRSULC_STG2)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                }
                if (!ValidateUtils.isEmptyCaret(NBR_PRSULC_STG3) && !ValidateUtils.isNumeric(NBR_PRSULC_STG3)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                }
                if (!ValidateUtils.isEmptyCaret(NBR_PRSULC_STG4) && !ValidateUtils.isNumeric(NBR_PRSULC_STG4)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                }
                if (!ValidateUtils.isEmptyCaret(NSTG_CVRG) && !ValidateUtils.isNumeric(NSTG_CVRG)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_CVRG, NSTG_CVRG)));
                }
                if (!ValidateUtils.isEmptyCaret(NSTG_DEEP_TISUE) && !ValidateUtils.isNumeric(NSTG_DEEP_TISUE)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DEEP_TISUE, NSTG_DEEP_TISUE)));
                }

                if (!ValidateUtils.isEmptyCaret(NSTG_DRSG) && !ValidateUtils.isNumeric(NSTG_DRSG)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DRSG, NSTG_DRSG)));
                }
                if (isRFA_1_3_9
                        && !ValidateUtils.isValidValue(STUS_PRBLM_PRSR_ULCR, ValidateUtils.ARRAY_DOUBLE_ZERO_ONE_TWO_THREE, ValidateUtils.ARRAY_CARET_VALUES, new String[]{ValidateUtils.NOT_APPLICABLE})) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1320_STUS_PRBLM_PRSR_ULCR, STUS_PRBLM_PRSR_ULCR)));
                }

                if (!ValidateUtils.isValidValue(STG_PRBLM_ULCER, ValidateUtils.ARRAY_DOUBLE_ONE_TWO_THREE_FOUR, new String[]{ValidateUtils.NOT_APPLICABLE})) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1324_STG_PRBLM_ULCER, STG_PRBLM_ULCER)));
                }

                /*ARRAY_
                 * edit 5110
                 */
                if ("0".equals(UNHLD_STG2_PRSR_ULCR)) {
                    if (!ValidateUtils.isEmpty(NBR_PRSULC_STG2)
                            || !ValidateUtils.isEmpty(NBR_PRSULC_STG3)
                            || !ValidateUtils.isEmpty(NBR_PRSULC_STG4)
                            || !ValidateUtils.isEmpty(NSTG_CVRG)
                            || !ValidateUtils.isEmpty(NSTG_DEEP_TISUE)
                            || !ValidateUtils.isEmpty(NSTG_DRSG)
                            || !ValidateUtils.isEmpty(STUS_PRBLM_PRSR_ULCR)) {
                        count++;
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1306_UNHLD_STG2_PRSR_ULCR, UNHLD_STG2_PRSR_ULCR)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_CVRG, NSTG_CVRG)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DRSG, NSTG_DRSG)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DEEP_TISUE, NSTG_DEEP_TISUE)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5110,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1320_STUS_PRBLM_PRSR_ULCR, STUS_PRBLM_PRSR_ULCR)));
                    }
                } else if ("1".equals(UNHLD_STG2_PRSR_ULCR)) {
                    if (ValidateUtils.isEmpty(NBR_PRSULC_STG2)
                            || ValidateUtils.isEmpty(NBR_PRSULC_STG3)
                            || ValidateUtils.isEmpty(NBR_PRSULC_STG4)
                            || ValidateUtils.isEmpty(NSTG_CVRG)
                            || ValidateUtils.isEmpty(NSTG_DEEP_TISUE)
                            || ValidateUtils.isEmpty(NSTG_DRSG)) {
                        count++;
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5120,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1306_UNHLD_STG2_PRSR_ULCR, UNHLD_STG2_PRSR_ULCR)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5120,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5120,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5120,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5120,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_CVRG, NSTG_CVRG)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5120,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DRSG, NSTG_DRSG)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5120,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DEEP_TISUE, NSTG_DEEP_TISUE)));

                    } else if (ValidateUtils.DOUBLE_ZERO.equals(NBR_PRSULC_STG2)
                            && ValidateUtils.DOUBLE_ZERO.equals(NBR_PRSULC_STG3)
                            && ValidateUtils.DOUBLE_ZERO.equals(NBR_PRSULC_STG4)
                            && ValidateUtils.DOUBLE_ZERO.equals(NSTG_CVRG)
                            && ValidateUtils.DOUBLE_ZERO.equals(NSTG_DRSG)
                            && ValidateUtils.DOUBLE_ZERO.equals(NSTG_DEEP_TISUE)) {
                        count++;
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5130,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5130,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5130,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5130,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_CVRG, NSTG_CVRG)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5130,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DRSG, NSTG_DRSG)));
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_5130,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DEEP_TISUE, NSTG_DEEP_TISUE)));
                    }
                } else {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1306_UNHLD_STG2_PRSR_ULCR, UNHLD_STG2_PRSR_ULCR)));
                }

                /*
                 * edit 4210
                 */
                if (ValidateUtils.DOUBLE_ZERO.equals(NBR_PRSULC_STG1)
                        && (ValidateUtils.DOUBLE_ZERO.equals(NBR_PRSULC_STG2) || ValidateUtils.isEmpty(NBR_PRSULC_STG2))
                        && (ValidateUtils.DOUBLE_ZERO.equals(NBR_PRSULC_STG3) || ValidateUtils.isEmpty(NBR_PRSULC_STG3))
                        && (ValidateUtils.DOUBLE_ZERO.equals(NBR_PRSULC_STG4) || ValidateUtils.isEmpty(NBR_PRSULC_STG4))
                        && !ValidateUtils.NOT_APPLICABLE.equals(STG_PRBLM_ULCER)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4210,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1322_NBR_PRSULC_STG1, NBR_PRSULC_STG1)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4210,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4210,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4210,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4210,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1324_STG_PRBLM_ULCER, STG_PRBLM_ULCER)));
                }

                /*
                 * convert the strings to number to makei it easier to check 
                 * greater than, because the greater than check no longer works
                 * with a string since "^ " (i.e. empty) is actually greater
                 * than "00"
                 */
                final int intStage2 = ValidateUtils.isEmpty(NBR_PRSULC_STG2) ? -1 : IntegerUtils.parseInt(NBR_PRSULC_STG2, -1);
                final int intStage3 = ValidateUtils.isEmpty(NBR_PRSULC_STG3) ? -1 : IntegerUtils.parseInt(NBR_PRSULC_STG3, -1);
                final int intStage4 = ValidateUtils.isEmpty(NBR_PRSULC_STG4) ? -1 : IntegerUtils.parseInt(NBR_PRSULC_STG4, -1);
                final int intNonStageCovering = ValidateUtils.isEmpty(NSTG_CVRG) ? -1 : IntegerUtils.parseInt(NSTG_CVRG, -1);
                final int intNonStageDeepTissue = ValidateUtils.isEmpty(NSTG_DEEP_TISUE) ? -1 : IntegerUtils.parseInt(NSTG_DEEP_TISUE, -1);

                /*
                 * edit 4130
                 */
                if (intStage2 == 0 && intStage3 == 0 && intStage4 == 0 && intNonStageCovering == 0
                        && intNonStageDeepTissue == 0
                        && isRFA_1_3_9
                        && !ValidateUtils.NOT_APPLICABLE.equals(STUS_PRBLM_PRSR_ULCR)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4130,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4130,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4130,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4130,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_CVRG, NSTG_CVRG)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4130,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DEEP_TISUE, NSTG_DEEP_TISUE)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4130,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1320_STUS_PRBLM_PRSR_ULCR, STUS_PRBLM_PRSR_ULCR)));
                }

                /*
                 * edit 4140
                 */
                if ((intStage2 > 0 || intNonStageDeepTissue > 0)
                        && intStage3 == 0 && intStage4 == 0 && intNonStageCovering == 0
                        && isRFA_1_3_9
                        && !"03".equals(STUS_PRBLM_PRSR_ULCR)) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4140,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4140,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4140,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4140,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_CVRG, NSTG_CVRG)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4140,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DEEP_TISUE, NSTG_DEEP_TISUE)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4140,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1320_STUS_PRBLM_PRSR_ULCR, STUS_PRBLM_PRSR_ULCR)));
                }

                /*
                 * edit 4150
                 */
                if ((intStage3 > 0 || intStage4 > 0)
                        && isRFA_1_3_9
                        && !ValidateUtils.isValidValue(STUS_PRBLM_PRSR_ULCR, ARRAY_DOUBLE_ZERO_ONE_TWO_THREE)) {
                    // if any stage x > 0, then the Status Problem Pressure Ucler
                    // must be 00, 01, 02, or 03, but only when RFA = 1 or 3
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4150,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4150,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4150,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1320_STUS_PRBLM_PRSR_ULCR, STUS_PRBLM_PRSR_ULCR)));
                }

                /*
                 * edit 4160
                 */
                if (intNonStageCovering > 0 && intStage2 == 0 && intStage3 == 0
                        && intStage4 == 0 && intNonStageDeepTissue == 0
                        && isRFA_1_3_9
                        && !("02".equals(STUS_PRBLM_PRSR_ULCR) || "03".equals(STUS_PRBLM_PRSR_ULCR))) {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4160,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG2, NBR_PRSULC_STG2)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4160,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG3, NBR_PRSULC_STG3)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4160,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NBR_PRSULC_STG4, NBR_PRSULC_STG4)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4160,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_CVRG, NSTG_CVRG)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4160,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1308_NSTG_DEEP_TISUE, NSTG_DEEP_TISUE)));
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4160,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1320_STUS_PRBLM_PRSR_ULCR, STUS_PRBLM_PRSR_ULCR)));
                }

                /*
                 * edit 4170
                 * edit 3060 for stage 1
                 */
                if (ValidateUtils.isValidValue(NBR_PRSULC_STG1, ARRAY_DOUBLE_ZERO_ONE_TWO_THREE_FOUR)) {
                    if ("01".equals(STG_PRBLM_ULCER)
                            && !ValidateUtils.isValidValue(NBR_PRSULC_STG1, ValidateUtils.ARRAY_DOUBLE_ONE_TWO_THREE_FOUR)) {
                        count++;
                        edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_4170,
                                new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1322_NBR_PRSULC_STG1, NBR_PRSULC_STG1)));
                    }
                } else {
                    count++;
                    edits.add(new OasisValidationEdit(OasisEditsEN.EDIT_3060,
                            new HHOasisDataItem(HomeHealthRecord_C1_IF.OASIS_C1_ITEM_M1322_NBR_PRSULC_STG1, NBR_PRSULC_STG1)));
                }
            }
        }

        return count;
    }

    /**
     * Gets the description
     *
     * @return non-null string
     */
    public String getDescription() {
        return "Validates Pressure Ulcers for Stage 1 thru 4, and Non-staging pressure ulcers for edits: 3060, 4130, 4140,4150, 4160, 4170, 4210, 5110, 5120, 5130";
    }

}
